ipak <- function(pkg){
	new.pkg <- pkg[!(pkg %in% installed.packages()[, "Package"])]
	if (length(new.pkg)) 
		install.packages(new.pkg, dependencies = TRUE)
	sapply(pkg, require, character.only = TRUE)
} #function to install and read packages automatically. From sevenworthington/ipak.R in github.com
packages<-c("ggplot2",
						"ggrepel",
						"gridExtra",
						"MASS",
						"ape",
						"picante",
						"caper",
						"phytools",
						"ade4",
						"geomorph",
						"car") #required packages
ipak(packages)
setwd("/Users/benjamin/Dropbox/PGLS whales/Appendix") #modify the path according the location of your own working folder
data<-read.csv("Supplement S2-measurements.csv",
							 header=T,
							 sep=";",
							 dec=",")
#dataset separation between forelimb and pterygoid sinuses
#pterygoid dataset
pterygoid<-data[,-(grep("for", colnames(data)))]
pterygoid<-pterygoid[complete.cases(pterygoid[,grep("pter",colnames(pterygoid))]),]
#forelimb dataset 
forelimb<-data[,-(grep("pter", colnames(data)))]
forelimb<-forelimb[complete.cases(forelimb[,grep("for",colnames(forelimb))]),]
rm("data")
#compute natural logarithm for the pterygoid
plog<-data.frame(pterygoid,
								 log(pterygoid[,grep("pter",colnames(pterygoid))])) #log raw measurements of the pterygoid
colnames(plog)[9]<-"LOG-AWP";
colnames(plog)[10]<-"LOG-PWP";
colnames(plog)[11]<-"LOG-LP";
colnames(plog)[12]<-"LOG-HP";
#compute log-shape ratio for the forelimb
fsize<-apply(forelimb[,4:14],
						 1,
						 prod)^(1/(ncol(forelimb[,grep("for",colnames(forelimb))]))) #geometric mean forelimb
fLSR<-data.frame(forelimb,
								 log(forelimb[,grep("for",colnames(forelimb))]/fsize)) #log-shape ratio forelimb 
colnames(fLSR)[16]<-"MLS-LSR";
colnames(fLSR)[17]<-"MHS-LSR";
colnames(fLSR)[18]<-"GLS-LSR";
colnames(fLSR)[19]<-"AHH-LSR";
colnames(fLSR)[20]<-"LH-LSR";
colnames(fLSR)[21]<-"DLH-LSR";
colnames(fLSR)[22]<-"WDTH-LSR";
colnames(fLSR)[23]<-"LR-LSR";
colnames(fLSR)[24]<-"MLR-LSR";
colnames(fLSR)[25]<-"PWR-LSR";
colnames(fLSR)[26]<-"DWR-LSR";
rm(list=c("fsize","forelimb","pterygoid"))
#compute median for each species
#median obtained from the pterygoid
med.plog<-aggregate(plog[,grep("LOG",colnames(plog))],
										list(plog$species),
										median)
colnames(med.plog)[1]<-"species"
med.plog<-unique(merge(med.plog,
											 plog[,-grep("pter|LOG|Ins",colnames(plog))],
											 by="species"))
rownames(med.plog)<-med.plog$species
#median obtained from the forelimb log-shape ratio
med.fLSR<-aggregate(fLSR[,grep("LSR",colnames(fLSR))],
										list(fLSR$species),
										median)
colnames(med.fLSR)[1]<-"species"
med.fLSR<-unique(merge(med.fLSR,
											 fLSR[,-grep("for|LSR|Ins",colnames(fLSR))],
											 by="species"))
rownames(med.fLSR)<-med.fLSR$species
#compute the trees
tree<-"(((((((((((((((Stenella_coeruleoalba:1.10,Stenella_clymene:1.10):0.79,Tursiops_truncatus:1.89):0.05,Stenella_frontalis:1.94):1.57,(Stenella_attenuata:3.14,Stenella_longirostris:3.14):0.37):3.47,Sotalia_fluviatilis:6.98):1.38,(((Pseudorca_crassidens:3.69,Globicephala_melas:3.69):0.51,Grampus_griseus:4.20):3.8,Orcaella_brevirostris:8.00):0.36):0.49,(Sagmatias_obscurus:3.20,Cephalorhynchus_commersoni:3.20):5.65):0.54,Lagenorhynchus_acutus:9.39):0.69,Orcinus_orca:10.08):8.58,(Monodon_monoceros:6.28,Delphinapterus_leucas:6:28):12.38):6.09,Pontoporia_blainvillei:24.75):6.47,((((((Mesoplodon_grayi:7.19,Mesoplodon_peruvianus:7.19):6.29,Mesoplodon_bowdoini:13.48):0.96,Mesoplodon_bidens:14.44):2.67,Hyperoodon_ampullatus:17.11):1.46,Ziphius_cavirostris:18.57):0.01,Messapicetus_gregarius:18.56):12.65):1.22,Platanista_gangetica:32.43):2.26,Physeter_macrocephalus:34.69):3.11,Dorudon_atrox:37.8);"
tree<-read.tree(text=tree)
plot(tree)
#pPCA
#drop branches not present in forelimb/pterygoid data
ptree<-drop.tip(tree,setdiff(tree$tip.label,med.plog$species))
ftree<-drop.tip(tree,setdiff(tree$tip.label,med.fLSR$species))
#pPCA LSR
lsr.ppca_pter<-phyl.pca(ptree,med.plog[,grep("LOG",colnames(med.plog))],
												method="BM",
												mode="corr") #pterygoid
lsr.ppca_for<-phyl.pca(ftree,
											 med.fLSR[,grep("LSR",colnames(med.fLSR))],
											 method="BM",
											 mode="corr") #forelimb
#create color vector pterygoid/diving specialisation 
tip.col1<-med.plog["Deep.diving_specialisation"]
levels(tip.col1[,1])<-c("darkgoldenrod1","coral2") #change the levels by a colors. darkgoldenrow1 = non deep-diver, coral2 = deep-diver
ordered_name<-ptree$tip.label
tip.col1_match<-tip.col1[match(ordered_name,rownames(tip.col1)),] #match the order of colors with the species in the tree
col1<-c(as.character(tip.col1_match),rep("black",ptree$Nnode)) #color the nodes in black
names(col1)<-1:(length(ptree$tip)+ptree$Nnode)
col1[is.na(col1)]<-"darkcyan" #change NA for darkcyan. 
rm(list=c("tip.col1","ordered_name","tip.col1_match"))
#create color vector forelimb
ftip.col1<-med.fLSR["Deep.diving_specialisation"]
levels(ftip.col1[,1])<-c("darkgoldenrod1","coral2")#change the levels by a colors. darkgoldenrow1 = non deep-diver, coral2 = deep-diver
ordered_name<-ftree$tip.label
ftip.col1_match<-ftip.col1[match(ordered_name,rownames(ftip.col1)),]
col2<-c(as.character(ftip.col1_match),rep("black",ftree$Nnode))
names(col2)<-1:(length(ftree$tip)+ftree$Nnode)
col2[is.na(col2)]<-"darkcyan" #change NA for darkcyan.
rm(list=c("ftip.col1","ftip.col1_match","ordered_name"))
#phylomorphospace pterygoid
perc_var_pter<-diag(lsr.ppca_pter$Eval)/sum(lsr.ppca_pter$Eval)*100 #percentage variance explained by each axis. Only n-1 PC are relevant here
phylomorphospace(ptree,
								 lsr.ppca_pter$S[,1:2],
								 label="horizontal",
								 xlab="Principal Component 1 (74.54%)",
								 ylab="Principal Component 2 (14.22%)",
								 control=list(col.node=col1)) 
add.simmap.legend(leg=c("non deep-diver",
												"deep-diver",
												"presumably non deep-diver"),
									colors=c("darkgoldenrod1",
													 "coral2",
													 "darkcyan"),
									prompt=FALSE,
									x=-15,
									y=10)#add the legend
s.corcircle(dfxy=lsr.ppca_pter$L[,1:2],
						xax=1,
						yax=2,
						label=row.names(lsr.ppca_pter$L)) #check direction of measurements variation
phylomorphospace(ptree,
								 lsr.ppca_pter$S[,c(1,3)],
								 label="horizontal",
								 xlab="Principal Component 1 (74.54%)",
								 ylab="Principal Component 3 (7.36%)",
								 control=list(col.node=col1)) 
s.corcircle(dfxy=lsr.ppca_pter$L[,c(1,3)],
						xax=1,
						yax=2,
						label=row.names(lsr.ppca_pter$L))
phylomorphospace(ptree,
								 lsr.ppca_pter$S[,2:3],
								 label="horizontal",
								 xlab="Principal Component 2 (14.22%)",
								 ylab="Principal Component 3 (7.36%)",
								 control=list(col.node=col1))
s.corcircle(dfxy=lsr.ppca_pter$L[,c(2,3)],
						xax=1,
						yax=2,
						label=row.names(lsr.ppca_pter$L))
#Phylomorphospace forelimb
#percentage variance explained by each axis
perc_var_for<-diag(lsr.ppca_for$Eval)/sum(lsr.ppca_for$Eval)*100 #only n-1 PC are relevant here
#plot phylomorphospace + loadings
phylomorphospace(ftree,
								 lsr.ppca_for$S[,1:2],
								 label="horizontal",
								 xlab="Principal Component 1 (26.07%)",
								 ylab="Principal Component 2 (19.48%)",
								 control=list(col.node=col2)) 
add.simmap.legend(leg=c("non deep-diver",
												"deep-diver",
												"presumably non deep-diver"),
									colors=c("darkgoldenrod1",
													 "coral2",
													 "darkcyan"),
									prompt=FALSE,
									x=5,
									y=-8)#add the legend
s.corcircle(dfxy=lsr.ppca_for$L[,1:2],
						xax=1,
						yax=2,
						label=row.names(lsr.ppca_for$L)) #check direction of measurements variation
phylomorphospace(ftree,
								 lsr.ppca_for$S[,2:3],
								 label="horizontal",
								 xlab="Principal Component 2 (19.48%)",
								 ylab="Principal Component 3 (17.79%)",
								 control=list(col.node=col2)) 
add.simmap.legend(leg=c("non deep-diver",
												"deep-diver",
												"presumably non deep-diver"),
									colors=c("darkgoldenrod1",
													 "coral2",
													 "darkcyan"),
									prompt=FALSE,
									x=-5,
									y=8)#add the legend
s.corcircle(dfxy=lsr.ppca_for$L[,c(2,3)],
						xax=1,
						yax=2,
						label=row.names(lsr.ppca_for$L))
phylomorphospace(ftree,
								 lsr.ppca_for$S[,c(1,3)],
								 label="horizontal",
								 xlab="Principal Component 1 (26.07%)",
								 ylab="Principal Component 3 (17.78%)",
								 control=list(col.node=col2)) 
add.simmap.legend(leg=c("non deep-diver",
												"deep-diver",
												"presumably non deep-diver"),
									colors=c("darkgoldenrod1",
													 "coral2",
													 "darkcyan"),
									prompt=FALSE,
									x=8,
									y=-5)#add the legend
s.corcircle(dfxy=lsr.ppca_for$L[,c(1,3)],
						xax=1,
						yax=2,
						label=row.names(lsr.ppca_for$L))
phylomorphospace(ftree,
								 lsr.ppca_for$S[,c(3,4)],
								 label="horizontal",
								 xlab="Principal Component 3 (17.78%)",
								 ylab="Principal Component 4 (10.61%)",
								 control=list(col.node=col2)) 
add.simmap.legend(leg=c("non deep-diver",
												"deep-diver",
												"presumably non deep-diver"),
									colors=c("darkgoldenrod1",
													 "coral2",
													 "darkcyan"),
									prompt=FALSE,
									x=-5,
									y=-8)#add the legend
s.corcircle(dfxy=lsr.ppca_for$L[,c(3,4)],
						xax=1,
						yax=2,
						label=row.names(lsr.ppca_for$L))
phylomorphospace(ftree,
								 lsr.ppca_for$S[,c(2,4)],
								 label="horizontal",
								 xlab="Principal Component 2 (19.48%)",
								 ylab="Principal Component 4 (10.61%)",
								 control=list(col.node=col2)) 
add.simmap.legend(leg=c("non deep-diver",
												"deep-diver",
												"presumably non deep-diver"),
									colors=c("darkgoldenrod1",
													 "coral2",
													 "darkcyan"),
									prompt=FALSE,
									x=-5,
									y=-8)#add the legend
s.corcircle(dfxy=lsr.ppca_for$L[,c(2,4)],
						xax=1,
						yax=2,
						label=row.names(lsr.ppca_for$L))

phylomorphospace(ftree,
								 lsr.ppca_for$S[,c(2,5)],
								 label="horizontal",
								 xlab="Principal Component 2 (19.48%)",
								 ylab="Principal Component 5 (9.37%)",
								 control=list(col.node=col2)) 
add.simmap.legend(leg=c("non deep-diver",
												"deep-diver",
												"presumably non deep-diver"),
									colors=c("darkgoldenrod1",
													 "coral2",
													 "darkcyan"),
									prompt=FALSE,
									x=-5,
									y=7)#add the legend
s.corcircle(dfxy=lsr.ppca_for$L[,c(2,5)],
						xax=1,
						yax=2,
						label=row.names(lsr.ppca_for$L))
#D-PGLS 
#D-PGLS foraging dive
pDPGLS<-med.plog[!(is.na(med.plog$Deep.diving_specialisation)),]#pterygoid dataset without Messapicetus gregarius
fDPGLS<-med.fLSR[!(is.na(med.fLSR$Deep.diving_specialisation)),]#forelimb dataset without Messapicetus gregarius
PGLS_ptree<-drop.tip(tree,setdiff(tree$tip.label,pDPGLS$species))
PGLS_ftree<-drop.tip(tree,setdiff(tree$tip.label,fDPGLS$species))

DPGLS_pter<-procD.pgls(pDPGLS[,grep("LOG",colnames(pDPGLS))]~pDPGLS$Deep.diving_specialisation,
											 phy=PGLS_ptree)#D-PGLS procedure for pterygoid
DPGLS_for<-procD.pgls(fDPGLS[,grep("LSR",colnames(fDPGLS))]~fDPGLS$Deep.diving_specialisation,
											phy=PGLS_ftree)#D-PGLS procedure for forelimb
summary(DPGLS_pter);summary(DPGLS_for)

#OLS
OLS_pter<-lm(as.matrix(pDPGLS[,grep("LOG",colnames(pDPGLS))])~pDPGLS$Deep.diving_specialisation)
OLS_for<-lm(as.matrix(fDPGLS[,grep("LSR",colnames(fDPGLS))])~fDPGLS$Deep.diving_specialisation)
summary(OLS_pter);summary(OLS_for)
Anova(OLS_pter); Anova(OLS_for)

